@@ -95,6 +95,31 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAICall(self, request):
+        """用于调用AI模型发起外呼通话，仅限自有电话号码使用，目前开通高级版座席**限时**免费体验。
+
+        发起通话前，请先确认您的AI模型是否兼容 OpenAI、Azure 或 Minimax 协议，并前往模型服务商网站获取相关鉴权信息。 具体功能说明请参考文档 [腾讯云联络中心AI通话平台](https://cloud.tencent.com/document/product/679/112100)。
+
+        :param request: Request instance for CreateAICall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAICallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAICallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAICall", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAICallResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAdminURL(self, request):
         """创建管理端访问链接
 
@@ -210,6 +235,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateCompanyApply(self, request):
+        """创建公司资质申请（1、首次使用接口，建议先在云联络中心控制台查看各个资料模板:https://console.cloud.tencent.com/ccc/enterprise/update。2、参数中图片Url建议使用腾讯云Cos存储的临时链接）
+
+        :param request: Request instance for CreateCompanyApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCompanyApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateCompanyApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCompanyApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCompanyApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateExtension(self, request):
         """创建话机账号
 
@@ -233,6 +281,52 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateIVRSession(self, request):
+        """创建关联 IVR 的会话，仅高级版支持，目前支持呼入和自动外呼两种 IVR 类型。收到请求后 TCCC 会先尝试呼通被叫，然后进入 IVR 流程。
+
+        :param request: Request instance for CreateIVRSession.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateIVRSessionRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateIVRSessionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateIVRSession", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateIVRSessionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateOwnNumberApply(self, request):
+        """创建客户自携号码接入审核
+
+        :param request: Request instance for CreateOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePredictiveDialingCampaign(self, request):
         """创建预测式外呼任务
 
@@ -441,7 +535,7 @@ class CccClient(AbstractClient):
 
 
     def DescribeAutoCalloutTasks(self, request):
-        """批量查询自动任务外呼
+        """批量查询自动外呼任务
 
         :param request: Request instance for DescribeAutoCalloutTasks.
         :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTasksRequest`
@@ -557,6 +651,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCompanyList(self, request):
+        """查询公司资质申请列表
+
+        :param request: Request instance for DescribeCompanyList.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeCompanyListRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeCompanyListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCompanyList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCompanyListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeExtension(self, request):
         """获取话机信息
 
@@ -649,6 +766,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeIvrAudioList(self, request):
+        """查询IVR音频文件列表信息
+
+        :param request: Request instance for DescribeIvrAudioList.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeIvrAudioListRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeIvrAudioListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIvrAudioList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeIvrAudioListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeNumbers(self, request):
         """查询号码列表
 
@@ -902,6 +1042,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTelRecordAsr(self, request):
+        """拉取会话录音转文本信息
+
+        :param request: Request instance for DescribeTelRecordAsr.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeTelRecordAsrResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTelRecordAsr", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTelRecordAsrResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTelSession(self, request):
         """获取 PSTN 会话信息
 
@@ -971,6 +1134,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyCompanyApply(self, request):
+        """修改公司资质申请，只能修改状态为驳回或待审核的申请单。（1、首次使用接口，建议先在云联络中心控制台查看各个资料模板:https://console.cloud.tencent.com/ccc/enterprise/update。2、参数中图片Url建议使用腾讯云Cos存储的临时链接）
+
+        :param request: Request instance for ModifyCompanyApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyCompanyApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ModifyCompanyApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyCompanyApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyCompanyApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyExtension(self, request):
         """修改话机账号(绑定技能组、绑定坐席账号)
 
@@ -994,6 +1180,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyOwnNumberApply(self, request):
+        """修改客户自携号码审批单
+
+        :param request: Request instance for ModifyOwnNumberApply.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ModifyOwnNumberApplyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyOwnNumberApply", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyOwnNumberApplyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyStaff(self, request):
         """修改客服账号
 
@@ -1017,6 +1226,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyStaffPassword(self, request):
+        """修改座席的密码
+
+        :param request: Request instance for ModifyStaffPassword.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ModifyStaffPasswordRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ModifyStaffPasswordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyStaffPassword", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyStaffPasswordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def PausePredictiveDialingCampaign(self, request):
         """暂停预测式外呼任务
 
@@ -1155,6 +1387,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateCCCSkillGroup(self, request):
+        """更新技能组
+
+        :param request: Request instance for UpdateCCCSkillGroup.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.UpdateCCCSkillGroupRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.UpdateCCCSkillGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateCCCSkillGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateCCCSkillGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdatePredictiveDialingCampaign(self, request):
         """任务未启动前，更新预测式外呼任务。
 
@@ -1171,6 +1426,29 @@ class CccClient(AbstractClient):
             model = models.UpdatePredictiveDialingCampaignResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UploadIvrAudio(self, request):
+        """上传IVR中使用的音频文件，每日上传文件限制50个。（参数中音频文件Url建议使用腾讯云Cos存储的临时链接）
+
+        :param request: Request instance for UploadIvrAudio.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.UploadIvrAudioRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.UploadIvrAudioResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UploadIvrAudio", params, headers=headers)
+            response = json.loads(body)
+            model = models.UploadIvrAudioResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
